https://github.com/lukel97 approved this pull request.
After https://github.com/llvm/llvm-project/pull/231400 all the SPEC CPU 2017 regressions are gone now on RISC-V, and we're seeing some nice gains. 525.x264_r is 3% faster due to better `satd_16x16` vectorization. I also checked and we get the similar improvements on x86-64 too. This was with the full "stack" of changes, including https://github.com/llvm/llvm-project/pull/196570 https://github.com/llvm/llvm-project/pull/197176 and https://github.com/llvm/llvm-project/pull/197678, so it would be good to land them together. LGTM, thanks for your patience https://github.com/llvm/llvm-project/pull/195886 _______________________________________________ cfe-commits mailing list [email protected] https://lists.llvm.org/cgi-bin/mailman/listinfo/cfe-commits
